#!/usr/bin/env python

import logging
import config
import msgs
from requests import post_json
from telegram.ext import Updater, CommandHandler

# Enable logging
logging.basicConfig(
        format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
        level=logging.INFO)

# Gather initial data to start
logger = logging.getLogger(__name__)
msg = msgs.start(config.get('language'))
chats = config.get('chat_ids')


def simple_msg(bot, update, message):
    if (str(update.message.chat_id) in chats):
        bot.sendMessage(chat_id=update.message.chat_id, text=message)
    else:
        bot.sendMessage(chat_id=update.message.chat_id, text=msg('forbidden'))


# Static methods
def start(bot, update):
    simple_msg(bot, update, msg('welcome'))


def help(bot, update):
    simple_msg(bot, update, msg('help') + get_webhook_names())


def error(bot, update, error):
    logger.warn('Update "%s" caused error "%s"' % (update, error))


def get_webhook_names():
    names = '\n'
    for webhook in config.get('webhooks'):
        names += '/' + webhook.get('command_name') + '\n'
    return names

def get_webhook_handler(webhook):
    def webhook_handler(bot, update):
        post_json(logger, webhook, update)

    return webhook_handler

def setup_webhooks(dp):
    for webhook in config.get('webhooks'):
        hook_handler = CommandHandler(webhook.get('command_name'), get_webhook_handler(webhook))
        dp.add_handler(hook_handler)


def main():
    # Create the EventHandler and pass it your bot's token.
    updater = Updater(token=config.get('bot_token'))

    # Get the dispatcher to register handlers
    dp = updater.dispatcher

    # Static command handlers
    start_handler = CommandHandler('start', start)
    help_handler = CommandHandler('help', help)

    # setup handlers
    dp.add_handler(start_handler)
    dp.add_handler(help_handler)

    setup_webhooks(dp)

    # log all errors
    dp.add_error_handler(error)

    # Start the Bot
    updater.start_polling()

    logger.info('Bot started')

    # Run the bot until the you presses Ctrl-C or the process receives SIGINT,
    # SIGTERM or SIGABRT. This should be used most of the time, since
    # start_polling() is non-blocking and will stop the bot gracefully.
    updater.idle()

if __name__ == '__main__':
    main()




from json import loads
from os.path import join, dirname

def start(key):
    msgFile = open(join(dirname(__file__), './messages.json'), 'r', encoding='utf-8')
    content = loads(msgFile.read())
    l10n_key = key

    def get(key):
        try:
            value = content[key][l10n_key]
        except KeyError:
            value = 'Translation key missing for key: %s' % key
        return value

    return get




import ssl
from json import dumps, loads, JSONDecodeError
from urllib.request import urlopen, Request
from urllib.error import HTTPError, URLError

def _get_parsed_data(logger, req_data, msg):
    parsed_data = None
    post_data = req_data.get('data', None)
    message = msg.message.text.replace('/' + req_data.get('command_name'), '')

    if post_data != None:
        if (req_data.get('headers').get('Content-Type') == 'application/json'):
            for key, val in post_data.items():
                post_data[key] = val % message
            parsed_data = dumps(post_data)
        else:
            try:
                parsed_data = post_data % message
            except ValueError as e:
                logger.warn(
                    'Failed to parse string, try to escape it:' +
                    'http://stackoverflow.com/q/8856523/151243'
                )
                parsed_data = post_data
            except TypeError as e:
                logger.warn('Could not format post data')
                parsed_data = post_data
        parsed_data = parsed_data.encode('utf8')

    logger.debug(parsed_data)

    return parsed_data


def post_json(logger, req_data, msg):
    parsed_data = _get_parsed_data(logger, req_data, msg)
    gcontext = ssl.SSLContext(ssl.PROTOCOL_TLSv1)

    try:
        req = Request(
            url=req_data['url'],
            data=parsed_data,
            headers=req_data.get('headers', {}),
            method=req_data.get('method', 'GET')
        )
    except KeyError as e:
        logger.error('A webhook must have a url property')

    try:
        http_res = urlopen(req, context=gcontext)
        res = http_res.read()
        try:
            parsed_res = loads(res.decode())
            logger.debug(parsed_res)
        except JSONDecodeError as e:
            logger.error(e)
            parsed_res = { 'response': res }
    except HTTPError as e:
        logger.error(e)
        parsed_res = {}
    except URLError as e:
        logger.error('Address could not be reached')
        parsed_res = {}

    return parsed_res




from json import loads
from os import getenv
from os.path import join, dirname

standard_location = join(dirname(__file__), './config.json')
config_file_path = getenv('TELEGRAM_PI_BOT_CONFIG', standard_location)
config_file = open(config_file_path, 'r', encoding='utf-8')
content = loads(config_file.read())

def get(key):
    return content[key]




from distutils.core import setup

setup(
    name = 'telegram-pi-bot',
    packages = ['telegram_pi_bot'],
    version = '0.1.7',
    description = 'A python-telegram-bot setup to run on Raspberry pi',
    author = 'Ruy Adorno',
    author_email = 'ruyadorno@hotmail.com',
    url = 'https://github.com/ruyadorno/telegram-pi-bot',
    download_url = 'https://github.com/ruyadorno/telegram-pi-bot/tarball/0.1.7',
    keywords = ['telegram', 'raspberrypi', 'bot', 'python-telegram-bot'],
    install_requires=['python-telegram-bot>=5,<6'],
    classifiers = [],
    entry_points = {
        'console_scripts': [
            'telegram-pi-bot = telegram_pi_bot.command_line:main'
        ]
    }
)

